@@ -4,7 +4,7 @@ from musicscore.musicstream.streamvoice import SimpleFormat
 from musicscore.musictree.treescoretimewise import TreeScoreTimewise
 import os
 
-path = os.path.abspath(__file__).split('.')[0]
+path = str(os.path.abspath(__file__).split('.')[0])
 
 
 class Test(TestCase):
@@ -12,7 +12,7 @@ class Test(TestCase):
         self.score = TreeScoreTimewise()
 
     def test_1(self):
-        sf = SimpleFormat(durations=[2, 2])
+        sf = SimpleFormat(quarter_durations=[2, 2])
         sf.chords[0].add_action_dynamics('ff')
         sf.chords[1].add_dynamics('ff')
 
